@@ -1,38 +1,45 @@
 ##' Convert images to Flash animations.
-##' This function opens a graphical device first to generate a sequence of
-##' images based on \code{expr}, then makes use of the commands in `SWF Tools'
-##' (\command{png2swf}, \command{jpeg2swf}, \command{pdf2swf}) to convert these images
-##' to a single Flash animation.
+##' This function opens a graphical device first to generate a
+##' sequence of images based on \code{expr}, then makes use of the
+##' commands in `SWF Tools' (\command{png2swf}, \command{jpeg2swf},
+##' \command{pdf2swf}) to convert these images to a single Flash
+##' animation.
 ##'
-##' @param expr an expression to generate animations; use either the animation
-##'   functions (e.g. \code{brownian.motion()}) in this package or a custom
-##'   expression (e.g. \code{for(i in 1:10) plot(runif(10), ylim = 0:1)}).
-##' @param img.name file name of the sequence of images (`pure' name; without
-##'   any format or extension)
+##' @param expr an expression to generate animations; use either the
+##' animation functions (e.g. \code{brownian.motion()}) in this
+##' package or a custom expression (e.g. \code{for(i in 1:10)
+##' plot(runif(10), ylim = 0:1)}).
+##' @param img.name file name of the sequence of images (`pure' name;
+##' without any format or extension)
 ##' @param swf.name file name of the Flash file
-##' @param swftools the path of `SWF Tools', e.g. \file{C:/swftools}. This
-##'   argument is to make sure that \code{png2swf}, \code{jpeg2swf} and
-##'   \code{pdf2swf} can be executed correctly. If it is \code{NULL}, it should
-##'   be guaranteed that these commands can be executed without the path; anyway,
-##' this function will try to find SWF Tools from Windows registry even if
+##' @param swftools the path of `SWF Tools',
+##' e.g. \file{C:/swftools}. This argument is to make sure that
+##' \code{png2swf}, \code{jpeg2swf} and \code{pdf2swf} can be executed
+##' correctly. If it is \code{NULL}, it should be guaranteed that
+##' these commands can be executed without the path; anyway, this
+##' function will try to find SWF Tools from Windows registry even if
 ##' it is not in the PATH variable.
-##' @param \dots other arguments passed to \code{\link{ani.options}}, e.g.
-##'   \code{ani.height} and \code{ani.width}, ...
-##' @return An integer indicating failure (-1) or success (0) of the converting
-##'   (refer to \code{\link[base]{system}}).
-##' @note Please download and install the SWF Tools before using this function:
-##'   \url{http://www.swftools.org}
+##' @param ... other arguments passed to \code{\link{ani.options}},
+##' e.g.  \code{ani.height} and \code{ani.width}, ...
+##' @return An integer indicating failure (-1) or success (0) of the
+##' converting (refer to \code{\link[base]{system}}).
+##' @note Please download and install the SWF Tools before using this
+##' function: \url{http://www.swftools.org}
 ##'
 ##' We can also set the path to SWF Tools by
 ##' \code{ani.options(swftools = 'path/to/swftools')}.
 ##'
 ##' \code{ani.options('ani.type')} can only be one of \code{png},
 ##' \code{pdf} and \code{jpeg}.
+##'
+##' Also note that PDF graphics can be compressed using Pdftk (if it
+##' is installed and \code{ani.options('pdftk')} has been set); see
+##' \code{\link{pdftk}}.
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link{saveMovie}}, \code{\link{saveLatex}},
 ##' \code{\link{saveHTML}}, \code{\link[base]{system}},
-##'   \code{\link[grDevices]{png}}, \code{\link[grDevices]{jpeg}},
-##'   \code{\link[grDevices]{pdf}}
+##' \code{\link[grDevices]{png}}, \code{\link[grDevices]{jpeg}},
+##' \code{\link[grDevices]{pdf}}, \code{\link{pdftk}}
 ##' @references
 ##'   \url{http://animation.yihui.name/animation:start#create_flash_animations}
 ##' @keywords dynamic device utilities
@@ -44,7 +51,7 @@
 ##'     cl.pch = c(16, 2))}, swf.name = "kNN.swf", interval = 1.5,
 ##' nmax=ifelse(interactive(), 40, 2))
 ##'
-##' ## from pdf (vector plot) to swf
+##' ## from pdf (vector plot) to swf; can set the option 'pdftk' to compress PDF
 ##' saveSWF({brownian.motion(pch = 21, cex = 5, col = "red", bg = "yellow")},
 ##'     swf.name = "brownian.swf", interval = 0.2,
 ##' nmax = 30, ani.dev = "pdf", ani.type = "pdf",
@@ -74,10 +81,17 @@ saveSWF = function(expr, img.name = "Rplot", swf.name = "animation.swf",
         ani.dev(img.fmt, width = ani.options('ani.width'),
                 height = ani.options('ani.height'))
     owd1 = setwd(owd)
-    expr
+    eval(expr)
     setwd(owd1)
     if (use.dev) dev.off()
 
+    ## compress PDF files
+    if (file.ext == 'pdf' && !is.null(ani.options('pdftk'))) {
+        for (f in list.files(path = dirname(img.name), pattern =
+                             sprintf('^%s[0-9]*\\.pdf$', img.name), full.names = TRUE))
+            pdftk(f)
+    }
+
     if (!is.null(ani.options('swftools'))) {
         swftools = ani.options('swftools')
     } else {
